/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.wso2.registry.ui.actions;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ActionContext;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.struts2.StrutsStatics;
import org.wso2.registry.jdbc.JDBCRegistry;
import org.wso2.registry.ui.WebAppConstants;
import org.wso2.registry.*;

import java.util.*;

public class ArtifactDetailsAction extends AbstractRegistryAction {

    private String path;
    private String author;
    private String description;
    private Date lastModified;
    private String mediaType;
    private Properties properties;
    
    private List tags = new ArrayList();
    private List comments = new ArrayList();
    private int rating = 0;

    public String execute() throws Exception {

        Registry registry = getRegistry();

        // if path is not set, we assume that root "/" is requested
        if (path == null || path.length() == 0) {
            path = RegistryConstants.ROOT_PATH;
        }

        Artifact artifact = registry.get(path);

        if (artifact.getAuthorUserName() != null) {
            this.author = artifact.getAuthorUserName();
        }

        if (artifact.getDescription() != null) {
            this.description = artifact.getDescription();
        }
        
        this.path = artifact.getPath();
        this.lastModified = artifact.getLastModified();
        this.mediaType = artifact.getMediaType();
        this.rating = registry.getAverageRating(artifact.getPath());

        Tag[] t = registry.getTags(artifact.getPath());
        for (int i = 0; i < t.length; i++) {
            tags.add(t[i].getTagName());
        }

        Comment[] c = registry.getComments(artifact.getPath());
        for (int i = 0; i < c.length; i++) {
            comments.add(c[i]);
        }

        return ActionSupport.SUCCESS;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Date getLastModified() {
        return lastModified;
    }

    public void setLastModified(Date lastModified) {
        this.lastModified = lastModified;
    }

    public String getMediaType() {
        return mediaType;
    }

    public void setMediaType(String mediaType) {
        this.mediaType = mediaType;
    }

    public Properties getProperties() {
        return properties;
    }

    public void setProperties(Properties properties) {
        this.properties = properties;
    }

    public int getRating() {
        return rating;
    }

    public void setRating(int rating) {
        this.rating = rating;
    }

    public List getTags() {
        return tags;
    }

    public void setTags(List tags) {
        this.tags = tags;
    }

    public List getComments() {
        return comments;
    }

    public void setComments(List comments) {
        this.comments = comments;
    }
}
